@@ -1,3 +1,19 @@
+# Copyright 2023 DARWIN EU (C)
+#
+# This file is part of PatientProfiles
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 #' Categorize a numeric variable
 #'
 #' @param x Table with individuals in the cdm
@@ -6,21 +22,24 @@
 #' @param variable Target variable that we want to categorize.
 #' @param categories List of lists of named categories with lower and upper
 #' limit.
+#' @param missingCategoryValue Value to assign to those individuals not in
+#' any named category. If NULL or NA, missing will values will be
+#' given.
+#' @param overlap TRUE if the categories given overlap
 #' @param tablePrefix The stem for the permanent tables that will be created. If
 #' NULL, temporary tables will be used throughout.
 #'
 #' @return tibble with the categorical variable added.
 #'
-#' @noRd
+#' @export
 #'
 #' @examples
 #' #'
 #' \donttest{
 #' library(DBI)
 #' library(duckdb)
-#' library(tibble)
 #' library(PatientProfiles)
-#' cohort1 <- tibble::tibble(
+#' cohort1 <- dplyr::tibble(
 #'   cohort_definition_id = c("1", "1", "1"),
 #'   subject_id = c("1", "2", "3"),
 #'   cohort_start_date = c(
@@ -31,7 +50,7 @@
 #'   )
 #' )
 #'
-#' person <- tibble::tibble(
+#' person <- dplyr::tibble(
 #'   person_id = c("1", "2", "3"),
 #'   gender_concept_id = c("8507", "8507", "8507"),
 #'   year_of_birth = c(1980, 1970, 2000),
@@ -54,6 +73,8 @@ addCategories <- function(x,
                           cdm,
                           variable,
                           categories,
+                          missingCategoryValue = "None",
+                          overlap = FALSE,
                           tablePrefix = NULL) {
   if (!isTRUE(inherits(x, "tbl_dbi"))) {
     cli::cli_abort("x is not a table")
@@ -69,30 +90,32 @@ addCategories <- function(x,
   checkmate::assertCharacter(tablePrefix, len = 1, null.ok = TRUE)
 
 
-  for (i in c(1:length(categories))) {
-    if (!is.null(names(categories)) && variable == names(categories)[i]){
+  for (i in seq_along(categories)) {
+    if (!is.null(names(categories)) && variable == names(categories)[i]) {
       cli::cli_warn(paste0(
         "Categories name '",
         names(categories)[i],
-        "' already existed in table, the original variable has been overwritten."
+        "' already existed, the original variable has been overwritten."
       ))
     }
   }
 
-  if (length(unique(names(categories))) < length((names(categories)))){
+  if (length(unique(names(categories))) < length((names(categories)))) {
     cli::cli_abort(
-      "Categories have repeated names, please rename the groups.")
+      "Categories have repeated names, please rename the groups."
+    )
   }
 
   if (is.null(names(categories))) {
-    nam <- paste0("category_", 1:length(categories))
+    nam <- paste0("category_", seq_along(categories))
   } else {
     nam <- names(categories)
   }
 
   categoryTibble <- list()
   for (k in seq_along(categories)) {
-    categoryTibble[[nam[k]]] <- checkCategory(categories[[k]])
+    categoryTibble[[nam[k]]] <- checkCategory(categories[[k]],
+                                              overlap = overlap)
   }
 
   for (k in seq_along(categories)) {
@@ -101,20 +124,52 @@ addCategories <- function(x,
 
     x <- dplyr::mutate(x, variable := .data[[variable]])
     x <- dplyr::mutate(x, !!name := as.character(NA))
-    for (i in 1:nrow(categoryTibbleK)) {
-      lower <- categoryTibbleK$lower_bound[i]
-      upper <- categoryTibbleK$upper_bound[i]
-      category <- categoryTibbleK$category_label[i]
+    if (!overlap) {
+      for (i in 1:nrow(categoryTibbleK)) {
+        lower <- categoryTibbleK$lower_bound[i]
+        upper <- categoryTibbleK$upper_bound[i]
+        category <- categoryTibbleK$category_label[i]
+        x <- x %>%
+          dplyr::mutate(!!name := dplyr::if_else(
+            is.na(.data[[name]]) &
+              .data$variable >= .env$lower &
+              .data$variable <= .env$upper,
+            .env$category,
+            .data[[name]]
+          ))
+      }
+    } else {
+      for (i in 1:nrow(categoryTibbleK)) {
+        lower <- categoryTibbleK$lower_bound[i]
+        upper <- categoryTibbleK$upper_bound[i]
+        category <- categoryTibbleK$category_label[i]
+        x <- x %>%
+          dplyr::mutate(!!name := dplyr::if_else(
+            is.na(.data[[name]]) &
+              .data$variable >= .env$lower &
+              .data$variable <= .env$upper,
+            .env$category,
+            dplyr::if_else(
+              !is.na(.data[[name]]) &
+                .data$variable >= .env$lower &
+                .data$variable <= .env$upper,
+              paste0(.data[[name]], "&&", .env$category),
+              .data[[name]]
+            )
+          ))
+      }
+    }
+
+    x <- dplyr::select(x, -"variable")
+
+    # add missing as category
+    if (!is.null(missingCategoryValue) && !is.na(missingCategoryValue)) {
       x <- x %>%
-        dplyr::mutate(!!name := dplyr::if_else(
-          is.na(.data[[name]]) &
-            .data$variable >= .env$lower &
-            .data$variable <= .env$upper,
-          .env$category,
-          .data[[name]]
+        dplyr::mutate(!!name := dplyr::if_else(!is.na(.data[[name]]),
+          .data[[name]],
+          .env$missingCategoryValue
         ))
     }
-    x <- dplyr::select(x, -"variable")
 
     if (!is.null(tablePrefix)) {
       x <- CDMConnector::computeQuery(
