@@ -1,3 +1,19 @@
+# Copyright 2023 DARWIN EU (C)
+#
+# This file is part of PatientProfiles
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 #' Compute demographic characteristics at a certain date
 #'
 #' @param x Table with individuals in the cdm
@@ -67,7 +83,7 @@ addDemographics <- function(x,
   }
 
   ## check for standard types of user error
-  person_variable <- checkX(x)
+  personVariable <- checkX(x)
   checkCdm(cdm, c("person", "observation_period"))
   checkmate::assertLogical(age, any.missing = FALSE, len = 1)
   checkmate::assertIntegerish(
@@ -93,12 +109,34 @@ addDemographics <- function(x,
   }
 
   # check variable names
-  if(age) {checkSnakeCase(ageName)}
-  if(sex) {checkSnakeCase(sexName)}
-  if(priorHistory) {checkSnakeCase(priorHistoryName)}
-  if(futureObservation) {checkSnakeCase(futureObservationName)}
+  if (age) {
+    ageName <- checkSnakeCase(ageName)
+  }
+  if (sex) {
+    sexName <- checkSnakeCase(sexName)
+  }
+  if (priorHistory) {
+    priorHistoryName <- checkSnakeCase(priorHistoryName)
+  }
+  if (futureObservation) {
+    futureObservationName <- checkSnakeCase(futureObservationName)
+  }
+
+  checkNewName(ageName, x)
+  checkNewName(sexName, x)
+  checkNewName(priorHistoryName, x)
+  checkNewName(futureObservationName, x)
+
+  if (age == TRUE ||  priorHistory == TRUE || futureObservation == TRUE) {
+  checkmate::assert_true(
+    inherits(x %>%
+               utils::head(1) %>%
+               dplyr::pull(indexDate),
+             c("Date", "POSIXt")))
+  }
 
   # Start code
+  startTibble <- x
   startNames <- names(x)
 
   personDetails <- cdm[["person"]] %>%
@@ -109,22 +147,22 @@ addDemographics <- function(x,
       "month_of_birth",
       "day_of_birth"
     ) %>%
-    dplyr::rename(!!person_variable := "person_id")
+    dplyr::rename(!!personVariable := "person_id")
 
   if (priorHistory == TRUE || futureObservation == TRUE) {
     # most recent observation period (in case there are multiple)
     obsPeriodDetails <- x %>%
-      dplyr::select(dplyr::all_of(c(person_variable, indexDate))) %>%
+      dplyr::select(dplyr::all_of(c(personVariable, indexDate))) %>%
       dplyr::distinct() %>%
       dplyr::inner_join(
         cdm[["observation_period"]] %>%
-          dplyr::rename(!!person_variable := "person_id") %>%
+          dplyr::rename(!!personVariable := "person_id") %>%
           dplyr::select(
-            dplyr::all_of(person_variable),
+            dplyr::all_of(personVariable),
             "observation_period_start_date",
             "observation_period_end_date"
           ),
-        by = person_variable
+        by = personVariable
       ) %>%
       dplyr::filter(.data$observation_period_start_date <=
         .data[[indexDate]] &
@@ -134,66 +172,37 @@ addDemographics <- function(x,
 
   # update dates
   if (age) {
-    # impose month
-    if (ageImposeMonth == TRUE) {
-      personDetails <- personDetails %>%
-        dplyr::mutate(month_of_birth = .env$ageDefaultMonth)
-    } else {
-      personDetails <- personDetails %>%
-        dplyr::mutate(month_of_birth = dplyr::if_else(
-          is.na(.data$month_of_birth),
-          .env$ageDefaultMonth,
-          .data$month_of_birth
-        ))
-    }
-    # impose day
-    if (ageImposeDay == TRUE) {
-      personDetails <- personDetails %>%
-        dplyr::mutate(day_of_birth = .env$ageDefaultDay)
-    } else {
-      personDetails <- personDetails %>%
-        dplyr::mutate(day_of_birth = dplyr::if_else(
-          is.na(.data$day_of_birth),
-          .env$ageDefaultDay,
-          .data$day_of_birth
-        ))
-    }
+    personDetails <- personDetails %>%
+      dplyr::filter(!is.na(.data$year_of_birth)) %>%
+      addDateOfBirth(cdm,
+        name = "date_of_birth",
+        missingDay = ageDefaultDay,
+        missingMonth = ageDefaultMonth,
+        imposeDay = ageImposeDay,
+        imposeMonth = ageImposeMonth
+      )
   }
 
-  personDetails <- personDetails %>%
-    dplyr::filter(!is.na(.data$year_of_birth)) %>%
-    dplyr::mutate(
-      year_of_birth1 = as.character(as.integer(.data$year_of_birth)),
-      month_of_birth1 = as.character(as.integer(.data$month_of_birth)),
-      day_of_birth1 = as.character(as.integer(.data$day_of_birth))
-    ) %>%
-    dplyr::mutate(birth_date = as.Date(
-      paste0(
-        .data$year_of_birth1,
-        "-",
-        .data$month_of_birth1,
-        "-",
-        .data$day_of_birth1
+  # join if not the person table
+  if (any(!c("person_id", "gender_concept_id") %in% colnames(x))) {
+    x <- x %>%
+      dplyr::left_join(
+        personDetails %>%
+          dplyr::select(dplyr::any_of(c(
+            personVariable,
+            "date_of_birth",
+            "gender_concept_id",
+            "observation_period_start_date",
+            "observation_period_end_date"
+          ))),
+        by = personVariable
       )
-    ))
-
-  x <- x %>%
-    dplyr::left_join(
-      personDetails %>%
-        dplyr::select(dplyr::any_of(c(
-          person_variable,
-          "birth_date",
-          "gender_concept_id",
-          "observation_period_start_date",
-          "observation_period_end_date"
-        ))),
-      by = person_variable
-    )
+  }
 
   if (priorHistory == TRUE || futureObservation == TRUE) {
     x <- x %>%
       dplyr::left_join(obsPeriodDetails,
-        by = c(person_variable, indexDate)
+        by = c(personVariable, indexDate)
       )
   }
 
@@ -239,6 +248,14 @@ addDemographics <- function(x,
       ))
     )
 
+  if (sex == TRUE) {
+    x <- x %>%
+      dplyr::mutate(!!sexName := dplyr::if_else(!is.na(.data[[sexName]]),
+        .data[[sexName]],
+        "None"
+      ))
+  }
+
   if (is.null(tablePrefix)) {
     x <- x %>%
       CDMConnector::computeQuery()
@@ -260,10 +277,14 @@ addDemographics <- function(x,
       cdm = cdm,
       variable = ageName,
       categories = ageGroup,
+      missingCategoryValue = "None",
       tablePrefix = tablePrefix
     )
   }
 
+  # put back the initial attributes to the output tibble
+  x <- x %>% addAttributes(startTibble)
+
   return(x)
 }
 
@@ -271,10 +292,10 @@ addDemographics <- function(x,
 
 ageQuery <- function(indexDate, name) {
   return(glue::glue('floor(dbplyr::sql(
-    sqlGetAge(
-      dialect = CDMConnector::dbms(cdm),
-      dob = "birth_date",
-      dateOfInterest = "{indexDate}"
+    CDMConnector::datediff(
+      start = "date_of_birth",
+      end = "{indexDate}",
+      interval = "year"
     )
   ))') %>%
     rlang::parse_exprs() %>%
@@ -330,9 +351,8 @@ futureObservationQuery <- function(indexDate, name) {
 #' \donttest{
 #' library(DBI)
 #' library(duckdb)
-#' library(tibble)
 #' library(PatientProfiles)
-#' cohort1 <- tibble::tibble(
+#' cohort1 <- dplyr::tibble(
 #'   cohort_definition_id = c("1", "1", "1"),
 #'   subject_id = c("1", "2", "3"),
 #'   cohort_start_date = c(
@@ -343,7 +363,7 @@ futureObservationQuery <- function(indexDate, name) {
 #'   )
 #' )
 #'
-#' person <- tibble::tibble(
+#' person <- dplyr::tibble(
 #'   person_id = c("1", "2", "3"),
 #'   gender_concept_id = c("8507", "8532", "8507"),
 #'   year_of_birth = c(2000, 1995, NA),
@@ -383,20 +403,6 @@ addAge <- function(x,
   return(x)
 }
 
-sqlGetAge <- function(dialect,
-                      dob,
-                      dateOfInterest) {
-  SqlRender::translate(
-    SqlRender::render(
-      "((YEAR(@date_of_interest) * 10000 + MONTH(@date_of_interest) * 100 +
-                      DAY(@date_of_interest)-(YEAR(@dob)* 10000 + MONTH(@dob) * 100 + DAY(@dob))) / 10000)",
-      dob = dob,
-      date_of_interest = dateOfInterest
-    ),
-    targetDialect = dialect
-  )
-}
-
 #' Compute the number of days till the end of the observation period at a
 #' certain date
 #'
@@ -417,9 +423,8 @@ sqlGetAge <- function(dialect,
 #' \donttest{
 #' library(DBI)
 #' library(duckdb)
-#' library(tibble)
 #' library(PatientProfiles)
-#' cohort1 <- tibble::tibble(
+#' cohort1 <- dplyr::tibble(
 #'   cohort_definition_id = c("1", "1", "1"),
 #'   subject_id = c("1", "2", "3"),
 #'   cohort_start_date = c(
@@ -434,7 +439,7 @@ sqlGetAge <- function(dialect,
 #'   )
 #' )
 #'
-#' obs_1 <- tibble::tibble(
+#' obs_1 <- dplyr::tibble(
 #'   observation_period_id = c("1", "2", "3"),
 #'   person_id = c("1", "2", "3"),
 #'   observation_period_start_date = c(
@@ -503,9 +508,8 @@ addFutureObservation <- function(x,
 #' \donttest{
 #' library(DBI)
 #' library(duckdb)
-#' library(tibble)
 #' library(PatientProfiles)
-#' cohort1 <- tibble::tibble(
+#' cohort1 <- dplyr::tibble(
 #'   cohort_definition_id = c("1", "1", "1"),
 #'   subject_id = c("1", "2", "3"),
 #'   cohort_start_date = c(
@@ -520,7 +524,7 @@ addFutureObservation <- function(x,
 #'   )
 #' )
 #'
-#' obs_1 <- tibble::tibble(
+#' obs_1 <- dplyr::tibble(
 #'   observation_period_id = c("1", "2", "3"),
 #'   person_id = c("1", "2", "3"),
 #'   observation_period_start_date = c(
@@ -596,9 +600,8 @@ addInObservation <- function(x,
                              indexDate = "cohort_start_date",
                              name = "in_observation",
                              tablePrefix = NULL) {
-
   ## check for standard types of user error
-  person_variable <- checkX(x)
+  personVariable <- checkX(x)
   checkCdm(cdm, c("observation_period"))
   checkVariableInX(indexDate, x)
   checkmate::assertCharacter(name, any.missing = FALSE, len = 1)
@@ -610,16 +613,18 @@ addInObservation <- function(x,
 
   x <- x %>%
     addDemographics(cdm,
-                    indexDate = indexDate,
-                    age = FALSE,
-                    sex = FALSE,
-                    priorHistory = TRUE,
-                    futureObservation = TRUE,
-                    tablePrefix = NULL
+      indexDate = indexDate,
+      age = FALSE,
+      sex = FALSE,
+      priorHistory = TRUE,
+      futureObservation = TRUE,
+      tablePrefix = NULL
     ) %>%
     dplyr::mutate(
       !!name := as.numeric(dplyr::if_else(
-        is.na(.data$prior_history)| is.na(.data$future_observation)|.data$prior_history < 0|.data$future_observation<0,0,1))) %>%
+        is.na(.data$prior_history) | is.na(.data$future_observation) | .data$prior_history < 0 | .data$future_observation < 0, 0, 1
+      ))
+    ) %>%
     dplyr::select(
       -"prior_history", -"future_observation"
     )
