@@ -1,6 +1,7 @@
 test_that("check input length and type for each of the arguments", {
   cdm <-
     mockPatientProfiles(
+      connectionDetails,
       seed = 1,
       patient_size = 5,
       latest_observation_start_date = "2019-01-01",
@@ -13,16 +14,13 @@ test_that("check input length and type for each of the arguments", {
   expect_error(addFutureObservation(cdm$cohort1, "cdm"))
 
   expect_error(addFutureObservation(cdm$cohort1, cdm, indexDate = "end_date"))
-
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("check condition_occurrence and cohort1 work", {
-
   # mock data
   cdm <-
     mockPatientProfiles(
+      connectionDetails,
       seed = 1,
       patient_size = 5,
       latest_observation_start_date = "2005-01-01",
@@ -35,13 +33,11 @@ test_that("check condition_occurrence and cohort1 work", {
   # check it works with condition_occurrence table in mockdb
   expect_true(typeof(cdm$condition_occurrence %>% addFutureObservation(cdm, indexDate = "condition_start_date") %>% dplyr::collect()) == "list")
   expect_true("future_observation" %in% colnames(cdm$condition_occurrence %>% addFutureObservation(cdm, indexDate = "condition_start_date")))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("check working example with cohort1", {
   # create mock tables for testing
-  cohort1 <- tibble::tibble(
+  cohort1 <- dplyr::tibble(
     cohort_definition_id = c("1", "1", "1"),
     subject_id = c("1", "2", "3"),
     cohort_start_date = c(
@@ -56,7 +52,7 @@ test_that("check working example with cohort1", {
     )
   )
 
-  obs_1 <- tibble::tibble(
+  obs1 <- dplyr::tibble(
     observation_period_id = c("1", "2", "3"),
     person_id = c("1", "2", "3"),
     observation_period_start_date = c(
@@ -73,9 +69,10 @@ test_that("check working example with cohort1", {
 
   cdm <-
     mockPatientProfiles(
+      connectionDetails,
       seed = 1,
       cohort1 = cohort1,
-      observation_period = obs_1
+      observation_period = obs1
     )
 
   result <- cdm$cohort1 %>%
@@ -86,7 +83,7 @@ test_that("check working example with cohort1", {
 
   expect_true(all(result %>%
     dplyr::select("future_observation") ==
-    tibble::tibble(
+    dplyr::tibble(
       future_observation =
         c(
           as.numeric(difftime(as.Date("2014-01-01"),
@@ -103,13 +100,11 @@ test_that("check working example with cohort1", {
           ))
         )
     )))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("check working example with condition_occurrence", {
   # create mock tables for testing
-  condition_occurrence <- tibble::tibble(
+  condition_occurrence <- dplyr::tibble(
     condition_occurrence_id = c("1", "1", "1"),
     person_id = c("1", "2", "3"),
     condition_start_date = c(
@@ -124,7 +119,7 @@ test_that("check working example with condition_occurrence", {
     )
   )
 
-  obs_1 <- tibble::tibble(
+  obs1 <- dplyr::tibble(
     observation_period_id = c("1", "2", "3"),
     person_id = c("1", "2", "3"),
     observation_period_start_date = c(
@@ -141,9 +136,10 @@ test_that("check working example with condition_occurrence", {
 
   cdm <-
     mockPatientProfiles(
+      connectionDetails,
       seed = 1,
       condition_occurrence = condition_occurrence,
-      observation_period = obs_1
+      observation_period = obs1
     )
 
   result <- cdm$condition_occurrence %>%
@@ -154,7 +150,7 @@ test_that("check working example with condition_occurrence", {
 
   expect_true(all(
     result %>% dplyr::select("future_observation") ==
-      tibble::tibble(
+      dplyr::tibble(
         future_observation =
           c(
             as.numeric(difftime(as.Date("2014-01-01"),
@@ -172,13 +168,11 @@ test_that("check working example with condition_occurrence", {
           )
       )
   ))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("different name", {
   # create mock tables for testing
-  condition_occurrence <- tibble::tibble(
+  condition_occurrence <- dplyr::tibble(
     condition_occurrence_id = c("1", "1", "1"),
     person_id = c("1", "2", "3"),
     condition_start_date = c(
@@ -193,7 +187,7 @@ test_that("different name", {
     )
   )
 
-  obs_1 <- tibble::tibble(
+  obs1 <- dplyr::tibble(
     observation_period_id = c("1", "2", "3"),
     person_id = c("1", "2", "3"),
     observation_period_start_date = c(
@@ -210,9 +204,10 @@ test_that("different name", {
 
   cdm <-
     mockPatientProfiles(
+      connectionDetails,
       seed = 1,
       condition_occurrence = condition_occurrence,
-      observation_period = obs_1
+      observation_period = obs1
     )
 
   cdm$condition_occurrence <-
@@ -222,22 +217,19 @@ test_that("different name", {
       futureObservationName = "fh"
     )
   expect_true("fh" %in% names(cdm$condition_occurrence))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("priorHistory and future_observation - outside of observation period", {
-
   # futureHistory should be NA if index date is outside of an observation period
 
-  person <- tibble::tibble(
+  person <- dplyr::tibble(
     person_id = c(1, 2),
     gender_concept_id = 1,
     year_of_birth = 1980,
     month_of_birth = 01,
     day_of_birth = 01
   )
-  observation_period <- tibble::tibble(
+  observation_period <- dplyr::tibble(
     observation_period_id = c(1, 2),
     person_id = c(1, 2),
     observation_period_start_date = c(
@@ -249,7 +241,7 @@ test_that("priorHistory and future_observation - outside of observation period",
       as.Date("2015-01-01")
     )
   )
-  cohort1 <- tibble::tibble(
+  cohort1 <- dplyr::tibble(
     cohort_definition_id = 1,
     subject_id = c(1, 2),
     cohort_start_date = as.Date(c("2012-02-01")),
@@ -257,6 +249,7 @@ test_that("priorHistory and future_observation - outside of observation period",
   )
 
   cdm <- mockPatientProfiles(
+    connectionDetails,
     person = person,
     observation_period = observation_period,
     cohort1 = cohort1
@@ -268,23 +261,20 @@ test_that("priorHistory and future_observation - outside of observation period",
     )
   # both should be NA
   expect_true(all(is.na(cdm$cohort1a %>% dplyr::pull(future_observation))))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("multiple observation periods", {
-
   # with multiple observation periods,
   # future history should relate to the current observation period
 
-  person <- tibble::tibble(
+  person <- dplyr::tibble(
     person_id = c(1, 2),
     gender_concept_id = 1,
     year_of_birth = 1980,
     month_of_birth = 01,
     day_of_birth = 01
   )
-  observation_period <- tibble::tibble(
+  observation_period <- dplyr::tibble(
     observation_period_id = c(1, 2, 3),
     person_id = c(1, 1, 2),
     observation_period_start_date = c(
@@ -298,7 +288,7 @@ test_that("multiple observation periods", {
       as.Date("2015-01-01")
     )
   )
-  cohort1 <- tibble::tibble(
+  cohort1 <- dplyr::tibble(
     cohort_definition_id = 1,
     subject_id = c(1, 2),
     cohort_start_date = as.Date(c("2012-02-01")),
@@ -306,6 +296,7 @@ test_that("multiple observation periods", {
   )
 
   cdm <- mockPatientProfiles(
+    connectionDetails,
     person = person,
     observation_period = observation_period,
     cohort1 = cohort1
@@ -334,6 +325,4 @@ test_that("multiple observation periods", {
       as.Date("2013-02-01"),
       units = "days"
     ))))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
