@@ -50,12 +50,18 @@ test_that("working examples", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
   result <- cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "date", nameStyle = "xx") %>%
-    dplyr::arrange(subject_id, cohort_start_date) %>%
-    dplyr::collect()
+    dplyr::arrange(subject_id, cohort_start_date)
+
+  expect_true(length(attributes(cdm$cohort1)) == length(attributes(result)))
+  for (i in names(attributes(cdm$cohort1))) {
+    if (i != "names" && i != "class") {
+      expect_true(identical(attr(cdm$cohort1, i), attr(result, i)))
+    }
+  }
 
   expect_true(colnames(result)[1] == "cohort_definition_id")
   expect_true(colnames(result)[2] == "subject_id")
@@ -64,18 +70,18 @@ test_that("working examples", {
 
   expect_true(all(result$xx == as.Date(c("2020-01-15", "2020-01-15", "2020-01-25", "2020-01-24", "2020-03-15"))))
 
-  result_1 <- cdm$cohort1 %>%
+  result1 <- cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "count") %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "days") %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "flag") %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(result_1$count_all_0_to_inf == c(4, 4, 3, 3, 1)))
-  expect_true(all(result_1$days_all_0_to_inf == c(14, 0, 5, 23, 43)))
-  expect_true(all(result_1$flag_all_0_to_inf == c(1, 1, 1, 1, 1)))
+  expect_true(all(result1$count_all_0_to_inf == c(4, 4, 3, 3, 1)))
+  expect_true(all(result1$days_all_0_to_inf == c(14, 0, 5, 23, 43)))
+  expect_true(all(result1$flag_all_0_to_inf == c(1, 1, 1, 1, 1)))
 
-  result_2 <-
+  result2 <-
     cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "count", order = "last") %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "flag", order = "last") %>%
@@ -84,17 +90,17 @@ test_that("working examples", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  result_6 <-
+  result6 <-
     cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = c("date", "count", "days", "flag"), order = "last") %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  for (col in colnames(result_2)) {
-    expect_true(all(result_2[[col]][!is.na(result_2[[col]])] == result_6[[col]][!is.na(result_6[[col]])]))
+  for (col in colnames(result2)) {
+    expect_true(all(result2[[col]][!is.na(result2[[col]])] == result6[[col]][!is.na(result6[[col]])]))
   }
 
-  expect_true(all(result_2$date_all_0_to_inf == as.Date(
+  expect_true(all(result2$date_all_0_to_inf == as.Date(
     c(
       "2020-02-16",
       "2020-02-16",
@@ -103,11 +109,11 @@ test_that("working examples", {
       "2020-03-15"
     )
   )))
-  expect_true(all(result_2$days_all_0_to_inf == c(46, 32, 27, 74, 43)))
-  expect_true(all(result_2$count_all_0_to_inf == c(4, 4, 3, 3, 1)))
-  expect_true(all(result_2$flag_all_0_to_inf == c(1, 1, 1, 1, 1)))
+  expect_true(all(result2$days_all_0_to_inf == c(46, 32, 27, 74, 43)))
+  expect_true(all(result2$count_all_0_to_inf == c(4, 4, 3, 3, 1)))
+  expect_true(all(result2$flag_all_0_to_inf == c(1, 1, 1, 1, 1)))
 
-  result_3 <-
+  result3 <-
     cdm$cohort1 %>%
     addIntersect(
       cdm = cdm,
@@ -132,14 +138,14 @@ test_that("working examples", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(result_3$date_all_minf_to_0 %in% as.Date(
+  expect_true(all(result3$date_all_minf_to_0 %in% as.Date(
     c(NA, "2020-01-15", "2020-01-15", NA, "2020-01-24")
   )))
-  expect_true(all(result_3$days_all_minf_to_0 %in% c(NA, 0, -5, NA, -8)))
-  expect_true(all(result_3$count_all_minf_to_0 == c(0, 1, 1, 0, 2)))
-  expect_true(all(result_3$flag_all_minf_to_0 == c(0, 1, 1, 0, 1)))
+  expect_true(all(result3$days_all_minf_to_0 %in% c(NA, 0, -5, NA, -8)))
+  expect_true(all(result3$count_all_minf_to_0 == c(0, 1, 1, 0, 2)))
+  expect_true(all(result3$flag_all_minf_to_0 == c(0, 1, 1, 0, 1)))
 
-  result_4 <- cdm$cohort1 %>%
+  result4 <- cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", window = list(c(-30, 30)), value = "date") %>%
     addIntersect(cdm = cdm, tableName = "cohort2", window = list(c(-30, 30)), value = "days") %>%
     addIntersect(cdm = cdm, tableName = "cohort2", window = list(c(-30, 30)), value = "count") %>%
@@ -147,7 +153,7 @@ test_that("working examples", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(result_4$date_all_m30_to_30 == as.Date(
+  expect_true(all(result4$date_all_m30_to_30 == as.Date(
     c(
       "2020-01-15",
       "2020-01-15",
@@ -156,11 +162,11 @@ test_that("working examples", {
       "2020-01-24"
     )
   )))
-  expect_true(all(result_4$days_all_m30_to_30 == c(14, 0, -5, 23, -8)))
-  expect_true(all(result_4$count_all_m30_to_30 == c(3, 3, 4, 2, 2)))
-  expect_true(all(result_4$flag_all_m30_to_30 == c(1, 1, 1, 1, 1)))
+  expect_true(all(result4$days_all_m30_to_30 == c(14, 0, -5, 23, -8)))
+  expect_true(all(result4$count_all_m30_to_30 == c(3, 3, 4, 2, 2)))
+  expect_true(all(result4$flag_all_m30_to_30 == c(1, 1, 1, 1, 1)))
 
-  result_5 <- cdm$cohort1 %>%
+  result5 <- cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", window = list(c(-30, 30)), value = "date", order = "last") %>%
     addIntersect(cdm = cdm, tableName = "cohort2", window = list(c(-30, 30)), value = "days", order = "last") %>%
     addIntersect(cdm = cdm, tableName = "cohort2", window = list(c(-30, 30)), value = "count", order = "last") %>%
@@ -169,10 +175,10 @@ test_that("working examples", {
     dplyr::collect()
 
 
-  expect_true(all(result_5$count_all_m30_to_30 == c(3, 3, 4, 2, 2)))
-  expect_true(all(result_5$flag_all_m30_to_30 == c(1, 1, 1, 1, 1)))
-  expect_true(all(result_5$days_all_m30_to_30 == c(25, 11, 27, 28, -3)))
-  expect_true(all(result_5$date_all_m30_to_30 == as.Date(
+  expect_true(all(result5$count_all_m30_to_30 == c(3, 3, 4, 2, 2)))
+  expect_true(all(result5$flag_all_m30_to_30 == c(1, 1, 1, 1, 1)))
+  expect_true(all(result5$days_all_m30_to_30 == c(25, 11, 27, 28, -3)))
+  expect_true(all(result5$date_all_m30_to_30 == as.Date(
     c(
       "2020-01-26",
       "2020-01-26",
@@ -181,8 +187,6 @@ test_that("working examples", {
       "2020-01-29"
     )
   )))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("working examples with cohort_end_date", {
@@ -237,7 +241,7 @@ test_that("working examples with cohort_end_date", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
   result <- cdm$cohort1 %>%
     addIntersect(
@@ -248,12 +252,9 @@ test_that("working examples with cohort_end_date", {
     dplyr::collect()
 
   expect_true(all(result$date_all_0_to_inf == as.Date(c("2020-01-25", "2020-01-15", "2020-01-25", "2020-01-24", "2020-03-15"))))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("working examples with extra column", {
-
   # functionality
   cohort1 <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 1, 1, 1),
@@ -305,17 +306,23 @@ test_that("working examples with extra column", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
-  cdm$cohort2 <- cdm$cohort2 %>% dplyr::mutate(measurment_result = row_number())
+  cdm$cohort2 <- cdm$cohort2 %>%
+    dbplyr::window_order(
+      .data$cohort_definition_id, .data$subject_id, .data$cohort_start_date
+    ) %>%
+    dplyr::mutate(measurment_result = dplyr::row_number()) %>%
+    dbplyr::window_order() %>%
+    CDMConnector::computeQuery()
 
   result <- cdm$cohort1 %>%
     addIntersect(cdm, "cohort2", c("flag", "measurment_result"), "cohort_definition_id", 1, "covid", list(c(0, Inf))) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  result_1 <- cdm$cohort1 %>%
-    addIntersect(cdm, "cohort2","measurment_result", "cohort_definition_id", 2, "covid", list(c(0, Inf))) %>%
+  result1 <- cdm$cohort1 %>%
+    addIntersect(cdm, "cohort2", "measurment_result", "cohort_definition_id", 2, "covid", list(c(0, Inf))) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
@@ -346,31 +353,37 @@ test_that("working examples with extra column", {
     ),
   )
 
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
 
-  cdm$cohort2 <- cdm$cohort2 %>% dplyr::mutate(measurment_result = row_number())
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
-  result_2 <- cdm$cohort1 %>%
+  cdm$cohort2 <- cdm$cohort2 %>%
+    dbplyr::window_order(
+      .data$cohort_definition_id, .data$subject_id, .data$cohort_start_date
+    ) %>%
+    dplyr::mutate(measurment_result = dplyr::row_number()) %>%
+    dbplyr::window_order() %>%
+    CDMConnector::computeQuery()
+
+  result2 <- cdm$cohort1 %>%
     addIntersect(cdm, "cohort2", "measurment_result",
-                 nameStyle = "{value}_{window_name}") %>%
+      nameStyle = "{value}_{window_name}"
+    ) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  result_3 <- cdm$cohort1 %>%
-    addIntersect(cdm, "cohort2", c("flag","measurment_result"),
-                 nameStyle = "{value}_{window_name}",
-                 window = list(c(-400,-200))) %>%
+  result3 <- cdm$cohort1 %>%
+    addIntersect(cdm, "cohort2", c("flag", "measurment_result"),
+      nameStyle = "{value}_{window_name}",
+      window = list(c(-400, -200))
+    ) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(result$measurment_result_covid_0_to_inf == c(1,1,2,6,5) ))
-  expect_true(all(is.na(result_1$measurment_result_na_0_to_inf )))
-  expect_true(all(result_2$measurment_result_0_to_inf == c("1; 2","1; 2",3,6,5) ))
-  expect_true(all(is.na(result_3$measurment_result_m400_to_m200 )))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
+  expect_true(all(result$measurment_result_covid_0_to_inf == c(1, 1, 2, 5, 7)))
+  expect_true(all(is.na(result1$measurment_result_covid_0_to_inf)))
+  expect_true(all(result2$measurment_result_0_to_inf == c("1; 2", "1; 2", 3, 5, 7)))
+  expect_true(all(is.na(result3$measurment_result_m400_to_m200)))
 })
 
 test_that("working examples with multiple cohort Ids", {
@@ -425,7 +438,7 @@ test_that("working examples with multiple cohort Ids", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -443,7 +456,7 @@ test_that("working examples with multiple cohort Ids", {
 
   expect_true(all(compareNA(result$date_id1_0_to_inf, as.Date(c("2020-01-15", "2020-01-15", "2020-01-25", NA, NA)))))
 
-  result_1 <- cdm$cohort1 %>%
+  result1 <- cdm$cohort1 %>%
     addIntersect(
       cdm = cdm, tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = 2, value = "count"
@@ -451,9 +464,9 @@ test_that("working examples with multiple cohort Ids", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(result_1$count_id2_0_to_inf == c(1, 1, 1, 1, 0)))
+  expect_true(all(result1$count_id2_0_to_inf == c(1, 1, 1, 1, 0)))
 
-  result_2 <- cdm$cohort1 %>%
+  result2 <- cdm$cohort1 %>%
     addIntersect(
       cdm = cdm, tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = c(1, 3), value = "flag"
@@ -469,7 +482,7 @@ test_that("working examples with multiple cohort Ids", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  result_3 <- cdm$cohort1 %>%
+  result3 <- cdm$cohort1 %>%
     addIntersect(
       cdm = cdm, tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = c(1, 3), value = c("count", "days", "flag")
@@ -477,18 +490,16 @@ test_that("working examples with multiple cohort Ids", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  for (col in colnames(result_2)) {
-    expect_true(all(result_2[[col]][!is.na(result_2[[col]])] == result_3[[col]][!is.na(result_3[[col]])]))
+  for (col in colnames(result2)) {
+    expect_true(all(result2[[col]][!is.na(result2[[col]])] == result3[[col]][!is.na(result3[[col]])]))
   }
 
-  expect_true(all(result_2$count_id1_0_to_inf == c(2, 2, 1, 0, 0)))
-  expect_true(all(compareNA(result_2$days_id1_0_to_inf, c(14, 0, 5, NA, NA))))
-  expect_true(all(result_2$flag_id1_0_to_inf == c(1, 1, 1, 0, 0)))
-  expect_true(all(result_2$count_id3_0_to_inf == c(1, 1, 1, 2, 1)))
-  expect_true(all(result_2$days_id3_0_to_inf == c(46, 32, 27, 23, 43)))
-  expect_true(all(result_2$flag_id3_0_to_inf == c(1, 1, 1, 1, 1)))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
+  expect_true(all(result2$count_id1_0_to_inf == c(2, 2, 1, 0, 0)))
+  expect_true(all(compareNA(result2$days_id1_0_to_inf, c(14, 0, 5, NA, NA))))
+  expect_true(all(result2$flag_id1_0_to_inf == c(1, 1, 1, 0, 0)))
+  expect_true(all(result2$count_id3_0_to_inf == c(1, 1, 1, 2, 1)))
+  expect_true(all(result2$days_id3_0_to_inf == c(46, 32, 27, 23, 43)))
+  expect_true(all(result2$flag_id3_0_to_inf == c(1, 1, 1, 1, 1)))
 })
 
 test_that("working examples calculating as incidence target cohort", {
@@ -523,7 +534,7 @@ test_that("working examples calculating as incidence target cohort", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -536,15 +547,13 @@ test_that("working examples calculating as incidence target cohort", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  result_1 <- cdm$cohort1 %>%
+  result1 <- cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "date", targetEndDate = NULL) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
   expect_true(all(result$test_all_0_to_inf == as.Date("2020-01-01")))
-  # expect_true(("all_0_to_inf" %in% colnames(result_1)))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
+  # expect_true(("all_0_to_inf" %in% colnames(result1)))
 })
 
 test_that("working examples with more than one window", {
@@ -599,7 +608,7 @@ test_that("working examples with more than one window", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -613,15 +622,13 @@ test_that("working examples with more than one window", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  result_1 <- cdm$cohort1 %>%
+  result1 <- cdm$cohort1 %>%
     addIntersect(cdm = cdm, tableName = "cohort2", value = "date", window = list(c(0, Inf), c(-Inf, 0))) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(result$date_all_0_to_inf == result_1$date_all_0_to_inf))
-  expect_true(all(compareNA(result$date_all_minf_to_0, result_1$date_all_minf_to_0)))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
+  expect_true(all(result$date_all_0_to_inf == result1$date_all_0_to_inf))
+  expect_true(all(compareNA(result$date_all_minf_to_0, result1$date_all_minf_to_0)))
 })
 
 test_that("working examples with tables, not cohorts", {
@@ -649,13 +656,13 @@ test_that("working examples with tables, not cohorts", {
     )
   )
 
-  drug_exposure <- dplyr::tibble(
+  drugExposure <- dplyr::tibble(
     subject_id = c(1, 1),
     drug_concept_id = c(1, 2),
     drug_exposure_start_date = as.Date(c("2020-02-10", "2019-09-01"))
   )
 
-  condition_occurrence <- dplyr::tibble(
+  conditionOccurrence <- dplyr::tibble(
     condition_concept_id = c(1, 1, 2, 2, 3, 3, 3),
     subject_id = c(1, 1, 1, 2, 2, 2, 1),
     condition_occurrence_start_date = as.Date(
@@ -682,7 +689,10 @@ test_that("working examples with tables, not cohorts", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, condition_occurrence = condition_occurrence, drug_exposure = drug_exposure)
+  cdm <- mockPatientProfiles(connectionDetails,
+                             cohort1 = cohort1,
+                             condition_occurrence = conditionOccurrence,
+                             drug_exposure = drugExposure)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -701,7 +711,7 @@ test_that("working examples with tables, not cohorts", {
 
   expect_true(all(result$date_all_0_to_inf %in% as.Date(c("2020-01-15", "2020-01-15", "2020-01-25", "2020-01-24", "2020-03-15"))))
 
-  result_1 <- cdm$condition_occurrence %>%
+  result1 <- cdm$condition_occurrence %>%
     addIntersect(
       cdm = cdm, tableName = "drug_exposure", value = "count",
       indexDate = "condition_occurrence_start_date",
@@ -712,13 +722,13 @@ test_that("working examples with tables, not cohorts", {
     dplyr::arrange(subject_id, condition_occurrence_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(result_1$count_id1_0_to_inf == c(1, 1, 1, 0, 0, 0, 0)))
+  expect_true(all(result1$count_id1_0_to_inf == c(1, 1, 1, 0, 0, 0, 0)))
   # test output all zero column when no result found
-  expect_true(all(result_1$count_id2_0_to_inf == c(0, 0, 0, 0, 0, 0, 0)))
-  expect_true(all(result_1$count_id1_minf_to_0 == c(0, 0, 0, 1, 0, 0, 0)))
-  expect_true(all(result_1$count_id2_minf_to_0 == c(1, 1, 1, 1, 0, 0, 0)))
+  expect_true(all(result1$count_id2_0_to_inf == c(0, 0, 0, 0, 0, 0, 0)))
+  expect_true(all(result1$count_id1_minf_to_0 == c(0, 0, 0, 1, 0, 0, 0)))
+  expect_true(all(result1$count_id2_minf_to_0 == c(1, 1, 1, 1, 0, 0, 0)))
 
-  result_2 <- cdm$condition_occurrence %>%
+  result2 <- cdm$condition_occurrence %>%
     addIntersect(
       cdm = cdm, tableName = "drug_exposure", value = "count",
       indexDate = "condition_occurrence_start_date",
@@ -728,10 +738,10 @@ test_that("working examples with tables, not cohorts", {
     dplyr::arrange(subject_id, condition_occurrence_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(result_1$count_id1_0_to_inf + result_1$count_id2_0_to_inf == result_2$count_all_0_to_inf))
-  expect_true(all(result_1$count_id1_minf_to_0 + result_1$count_id2_minf_to_0 == result_2$count_all_minf_to_0))
+  expect_true(all(result1$count_id1_0_to_inf + result1$count_id2_0_to_inf == result2$count_all_0_to_inf))
+  expect_true(all(result1$count_id1_minf_to_0 + result1$count_id2_minf_to_0 == result2$count_all_minf_to_0))
 
-  result_3 <- cdm$condition_occurrence %>%
+  result3 <- cdm$condition_occurrence %>%
     addIntersect(
       cdm = cdm, tableName = "drug_exposure", value = "date",
       indexDate = "condition_occurrence_start_date",
@@ -742,9 +752,9 @@ test_that("working examples with tables, not cohorts", {
     dplyr::arrange(subject_id, condition_occurrence_start_date) %>%
     dplyr::collect()
   # test output all zero column when no result found
-  expect_true(all(is.na(result_3$date_id2_0_to_inf)))
+  expect_true(all(is.na(result3$date_id2_0_to_inf)))
 
-  result_4 <- cdm$condition_occurrence %>%
+  result4 <- cdm$condition_occurrence %>%
     addIntersect(
       cdm = cdm, tableName = "drug_exposure", value = "days",
       indexDate = "condition_occurrence_start_date",
@@ -755,9 +765,7 @@ test_that("working examples with tables, not cohorts", {
     dplyr::arrange(subject_id, condition_occurrence_start_date) %>%
     dplyr::collect()
   # test output all zero column when no result found
-  expect_true(all(is.na(result_4$days_id2_0_to_inf)))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
+  expect_true(all(is.na(result4$days_id2_0_to_inf)))
 })
 
 test_that("check input length and type for each of the arguments", {
@@ -811,7 +819,7 @@ test_that("check input length and type for each of the arguments", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
   expect_error(addIntersect("cdm$cohort1", cdm))
 
@@ -830,12 +838,10 @@ test_that("check input length and type for each of the arguments", {
   expect_error(addIntersect(cdm$cohort1, cdm, tableName = "cohort2", value = "flag", targetEndDate = NA))
 
   expect_error(addIntersect(cdm$cohort1, cdm, tableName = "cohort2", value = "flag", nameStyle = "test_{nowindow}_{cohortName}"))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("test checkWindow function", {
-  cdm <- mockPatientProfiles()
+  cdm <- mockPatientProfiles(connectionDetails)
 
   expect_error(cdm$cohort1 %>%
     addIntersect(
@@ -846,7 +852,6 @@ test_that("test checkWindow function", {
       tableName = "cohort2",
       window = c(150, -90)
     ))
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("test if column exist, overwrite", {
@@ -904,7 +909,7 @@ test_that("test if column exist, overwrite", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
   result <- cdm$cohort1 %>%
     addIntersect(
@@ -937,8 +942,6 @@ test_that("test if column exist, overwrite", {
     cohort1 %>%
       dplyr::arrange(cohort_start_date, subject_id) %>%
       dplyr::select(date_all_0_to_30), na.rm = TRUE))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("overlapTable is empty, check return columns", {
@@ -993,7 +996,7 @@ test_that("overlapTable is empty, check return columns", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
 
   result <- cdm$cohort1 %>%
@@ -1005,8 +1008,10 @@ test_that("overlapTable is empty, check return columns", {
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(c("count_id2_0_to_inf", "flag_id2_0_to_inf", "days_id2_0_to_inf",
-                    "date_id2_0_to_inf") %in% colnames(result)))
+  expect_true(all(c(
+    "count_id2_0_to_inf", "flag_id2_0_to_inf", "days_id2_0_to_inf",
+    "date_id2_0_to_inf"
+  ) %in% colnames(result)))
 
   expect_true(all(result$count_id2_0_to_inf == 0))
 
@@ -1015,8 +1020,6 @@ test_that("overlapTable is empty, check return columns", {
   expect_true(all(is.na(result$days_na_0_to_inf)))
 
   expect_true(all(is.na(result$date_id2_0_to_inf)))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
 
 test_that("overlap is empty or not, multiple ids, check return columns", {
@@ -1073,7 +1076,7 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
     ),
   )
 
-  cdm <- mockPatientProfiles(cohort1 = cohort1, cohort2 = cohort2)
+  cdm <- mockPatientProfiles(connectionDetails, cohort1 = cohort1, cohort2 = cohort2)
 
   compareNA <- function(v1, v2) {
     same <- (v1 == v2) | (is.na(v1) & is.na(v2))
@@ -1130,28 +1133,30 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
       cdm = cdm, tableName = "cohort2",
       value = c("flag", "date"),
       filterVariable = "cohort_definition_id",
-      filterId = c(1,2,3),
-      window = list(c(0,Inf), c(-30,-1)),
+      filterId = c(1, 2, 3),
+      window = list(c(0, Inf), c(-30, -1)),
       idName = c("num1", "num2", "num3")
     ) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(c("flag_num1_0_to_inf", "flag_num2_0_to_inf", "flag_num3_0_to_inf",
-                    "date_num1_0_to_inf", "date_num2_0_to_inf", "date_num3_0_to_inf",
-                    "flag_num1_m30_to_m1", "flag_num2_m30_to_m1", "flag_num3_m30_to_m1",
-                    "date_num1_m30_to_m1", "date_num2_m30_to_m1", "date_num3_m30_to_m1")
-                  %in% colnames(result)))
+  expect_true(all(c(
+    "flag_num1_0_to_inf", "flag_num2_0_to_inf", "flag_num3_0_to_inf",
+    "date_num1_0_to_inf", "date_num2_0_to_inf", "date_num3_0_to_inf",
+    "flag_num1_m30_to_m1", "flag_num2_m30_to_m1", "flag_num3_m30_to_m1",
+    "date_num1_m30_to_m1", "date_num2_m30_to_m1", "date_num3_m30_to_m1"
+  )
+  %in% colnames(result)))
 
   expect_true(all(compareNA(result$date_num3_0_to_inf, c("2020-03-03", "2020-03-03", "2020-03-03", "2020-03-03", "2020-03-03", "2020-03-03", NA))))
   expect_true(all(compareNA(result$date_num3_m30_to_m1, c(NA, NA, NA, NA, NA, NA, "2020-03-03"))))
   expect_true(all(result$flag_num3_0_to_inf == c(1, 1, 1, 1, 1, 1, 0)))
-  expect_true(all(result$flag_num3_m30_to_m1 == c(0,0,0,0,0,0,1)))
+  expect_true(all(result$flag_num3_m30_to_m1 == c(0, 0, 0, 0, 0, 0, 1)))
 
-  expect_true(all(result$flag_num2_0_to_inf == c(0,0,0,0,0,0,0)))
-  expect_true(all(result$flag_num1_0_to_inf == c(0,0,0,0,0,0,0)))
-  expect_true(all(result$flag_num2_m30_to_m1 == c(0,0,0,0,0,0,0)))
-  expect_true(all(result$flag_num1_m30_to_m1 == c(0,0,0,0,0,0,0)))
+  expect_true(all(result$flag_num2_0_to_inf == c(0, 0, 0, 0, 0, 0, 0)))
+  expect_true(all(result$flag_num1_0_to_inf == c(0, 0, 0, 0, 0, 0, 0)))
+  expect_true(all(result$flag_num2_m30_to_m1 == c(0, 0, 0, 0, 0, 0, 0)))
+  expect_true(all(result$flag_num1_m30_to_m1 == c(0, 0, 0, 0, 0, 0, 0)))
 
   expect_true(all(is.na(result$date_num2_0_to_inf)))
   expect_true(all(is.na(result$date_num1_0_to_inf)))
@@ -1159,35 +1164,34 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
   expect_true(all(is.na(result$date_num1_m30_to_m1)))
 
   expect_error(cdm$cohort1 %>%
-                 addCohortIntersectDate(
-                   cdm = cdm,
-                   targetCohortTable =  "cohort2",
-                   targetCohortId = c(1,2,3),
-                   window = list(c(0,Inf), c(-30,-1))
-                 ) %>%
-                 dplyr::arrange(subject_id, cohort_start_date) %>%
-                 dplyr::collect())
+    addCohortIntersectDate(
+      cdm = cdm,
+      targetCohortTable = "cohort2",
+      targetCohortId = c(1, 2, 3),
+      window = list(c(0, Inf), c(-30, -1))
+    ) %>%
+    dplyr::arrange(subject_id, cohort_start_date) %>%
+    dplyr::collect())
 
   result <- cdm$cohort1 %>%
     addCohortIntersectDate(
       cdm = cdm,
-      targetCohortTable =  "cohort2",
-      targetCohortId = c(1,3),
-      window = list(c(0,Inf), c(-30,-1))
+      targetCohortTable = "cohort2",
+      targetCohortId = c(1, 3),
+      window = list(c(0, Inf), c(-30, -1))
     ) %>%
     dplyr::arrange(subject_id, cohort_start_date) %>%
     dplyr::collect()
 
-  expect_true(all(c("cohort_3_m30_to_m1", "cohort_1_m30_to_m1",
-                    "cohort_3_0_to_inf", "cohort_1_0_to_inf")
-                  %in% colnames(result)))
+  expect_true(all(c(
+    "cohort_3_m30_to_m1", "cohort_1_m30_to_m1",
+    "cohort_3_0_to_inf", "cohort_1_0_to_inf"
+  )
+  %in% colnames(result)))
 
   expect_true(all(compareNA(result$cohort_3_0_to_inf, c("2020-03-03", "2020-03-03", "2020-03-03", "2020-03-03", "2020-03-03", "2020-03-03", NA))))
   expect_true(all(compareNA(result$cohort_3_m30_to_m1, c(NA, NA, NA, NA, NA, NA, "2020-03-03"))))
 
   expect_true(all(is.na(result$cohort_1_m30_to_m1)))
   expect_true(all(is.na(result$cohort_1_0_to_inf)))
-
-  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
-
